@@ -1,10 +1,10 @@
 # package-level docstring
-__doc__ = '''
+"""
 DRSlib - a set of utilities by DavidRodriguezSoaresCUI
 ======================================================
 
 **DRSlib** is a Python package that provides a wide range of small
-yet powerful set of highly-reusable functions, classes, 
+yet powerful set of highly-reusable functions, classes,
 decorators, etc. Its main purpose is to provide high-level
 "building blocks" that accomplish simple tasks, facilitating
 the writing of elaborate scripts with limited code.
@@ -14,4 +14,4 @@ License: see *LICENSE file*
 Author: **DavidRodriguezSoaresCUI**
 
 Check its `Github repository <https://github.com/DavidRodriguezSoaresCUI/DRSlib>`_ and its `Pypi project page <https://pypi.org/project/DRSlib-DavidRodriguezSoaresCUI/>`_ .
-'''
+"""
