@@ -1,7 +1,7 @@
 ﻿# pylint: disable=too-few-public-methods
 
-# module-level docstring
-__doc__='''
+
+__doc__ = """
 OS detection module
 ===================
 
@@ -11,10 +11,11 @@ be written.
 I am not the original author of this class. It was downloaded from:
 https://github.com/scivision/pybashutils/blob/master/pybashutils/os_detect.py
 
-'''
+"""
 
 from platform import system, uname
 
+
 class Os:
     """
     returns class with properties:
@@ -37,25 +38,25 @@ class Os:
         self.windows = False
         self.bsd = False
 
-        if 'cygwin' in syst:
+        if "cygwin" in syst:
             self.cygwin = True
-            self.os = 'cygwin'
-        elif 'darwin' in syst:
+            self.os = "cygwin"
+        elif "darwin" in syst:
             self.mac = True
-            self.os = 'mac'
-        elif 'linux' in syst:
-            if 'Microsoft' in uname().release:
+            self.os = "mac"
+        elif "linux" in syst:
+            if "Microsoft" in uname().release:
                 self.wsl = True
-                self.os = 'wsl'
+                self.os = "wsl"
             else:
                 self.linux = True
-                self.os = 'linux'
-        elif 'windows' in syst:
+                self.os = "linux"
+        elif "windows" in syst:
             self.windows = True
-            self.os = 'windows'
-        elif 'bsd' in syst:
+            self.os = "windows"
+        elif "bsd" in syst:
             self.bsd = True
-            self.os = 'bsd'
+            self.os = "bsd"
 
     def __str__(self):
         return self.os
